<!--

@license Apache-2.0

Copyright (c) 2018 The Stdlib Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

-->

# isCircular

[![NPM version][npm-image]][npm-url] [![Build Status][test-image]][test-url] [![Coverage Status][coverage-image]][coverage-url] [![dependencies][dependencies-image]][dependencies-url]

> Test if an object-like value contains a circular reference.

<section class="installation">

## Installation

```bash
npm install @stdlib/assert-is-circular
```

</section>

<section class="usage">

## Usage

```javascript
var isCircular = require( '@stdlib/assert-is-circular' );
```

#### isCircular( value )

Test if an object-like `value` contains a circular reference.

```javascript
var obj = {
    'beep': 'boop'
};
var bool = isCircular( obj );
// returns false

obj.self = obj;
bool = isCircular( obj );
// returns true
```

</section>

<!-- /.usage -->

<!-- /.usage -->

<section class="notes">

## Notes

-   Object-like values include `objects` (except for `null`), `arrays`, `functions`, regular expressions, `Date` objects, and any other JavaScript object to which properties may be bound.

</section>

<!-- /.notes -->

<section class="examples">

## Examples

<!-- eslint-disable no-empty-function -->

<!-- eslint no-undef: "error" -->

```javascript
var isCircular = require( '@stdlib/assert-is-circular' );

var obj1 = {
    'a': 'beep',
    'b': {
        'c': 'boop'
    }
};
obj1.b.self = obj1;
var bool = isCircular( obj1 );
// returns true

var obj2 = {
    'a': {},
    'b': obj1
};
bool = isCircular( obj2 );
// returns true

var arr = [ 1, 2, 3 ];
arr.push( arr );
bool = isCircular( arr );
// returns true

function circ() {}
circ.self = circ;
bool = isCircular( circ );
// returns true

var obj3 = {
    'beep': 'boop'
};
bool = isCircular({
    'a': obj3,
    'b': obj3
});
// returns false

bool = isCircular( {} );
// returns false

bool = isCircular( null );
// returns false
```

</section>

<!-- /.examples -->


<section class="main-repo" >

* * *

## Notice

This package is part of [stdlib][stdlib], a standard library for JavaScript and Node.js, with an emphasis on numerical and scientific computing. The library provides a collection of robust, high performance libraries for mathematics, statistics, streams, utilities, and more.

For more information on the project, filing bug reports and feature requests, and guidance on how to develop [stdlib][stdlib], see the main project [repository][stdlib].

---

## License

See [LICENSE][stdlib-license].


## Copyright

Copyright &copy; 2016-2021. The Stdlib [Authors][stdlib-authors].

</section>

<!-- /.stdlib -->

<!-- Section for all links. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->

<section class="links">

[npm-image]: http://img.shields.io/npm/v/@stdlib/assert-is-circular.svg
[npm-url]: https://npmjs.org/package/@stdlib/assert-is-circular

[test-image]: https://github.com/stdlib-js/assert-is-circular/actions/workflows/test.yml/badge.svg
[test-url]: https://github.com/stdlib-js/assert-is-circular/actions/workflows/test.yml

[coverage-image]: https://img.shields.io/codecov/c/github/stdlib-js/assert-is-circular/main.svg
[coverage-url]: https://codecov.io/github/stdlib-js/assert-is-circular?branch=main

[dependencies-image]: https://img.shields.io/david/stdlib-js/assert-is-circular
[dependencies-url]: https://david-dm.org/stdlib-js/assert-is-circular/main

[stdlib]: https://github.com/stdlib-js/stdlib

[stdlib-authors]: https://github.com/stdlib-js/stdlib/graphs/contributors

[stdlib-license]: https://raw.githubusercontent.com/stdlib-js/assert-is-circular/main/LICENSE

</section>

<!-- /.links -->
